# Invpy package v1.2.0

- Package that includes several methods to compute statistical translation non-invariance of primarly, but not limitted to, scalar
cosmological fields.

## Updates v1.2.0

- pbc_estimator.py method is working correctly;
- added another routine called sigma_bias_which_diagonal_cs, in order to compute the bias
of the estimators in configuration space.

## Ongoing tests on (This item updates every new version)

### v1.2.0

- Tests to be made on Fourier space and configuration space for nopbc_estimator.py is ongoing.

## Older versions updates


### Major Bug fixes on v1.1.2

- Fixed normalization factor problem on sigma_bias_which_diagonal routine.

### Minor Bug fixes on v1.1.1

- Fixed bug of 'unexpected keyword argument estimator_kind' on sigma_which_diagonal routine of pbc_estimator.py method. 

### Major Bug fixes on v1.1.0

- Fixed second and first kind estimator bias in pbc_estimators.py method.
- Fixed second kind estimator bias in pbc_estimators.py method;
- Fixed bugs on common.py.






